[![Fastgplearn](./img.jpg)](https://gitee.com/boliqq07/fastgplearn)


[![Python Versions](https://img.shields.io/pypi/pyversions/fastgplearn.svg)](https://pypi.org/project/fastgplearn/)
![pypi Versions](https://badge.fury.io/py/fastgplearn.svg)
[![Documentation Status](https://readthedocs.org/projects/fastgplearn-en/badge/?version=latest)](https://fastgplearn-en.readthedocs.io/en/latest/?badge=latest)

FastGPLearn
------------------------
Welcome to FastGPLearn.

FastGPLearn implements Genetic Programming in Python, with a ``scikit-learn`` inspired and compatible API.
And the FastGPLearn applied the ``torch`` and ``numpy`` backend for fast calculated, make it accessible for ``CUDA`` .

FastGPLearn inspired by
[gplearn](https://gplearn.readthedocs.io/en/stable/intro.html),
[BGP](https://bgp.readthedocs.io/en/latest/index.html),


Document
----------------------
[fastgplearn document (English)](https://fastgplearn-en.readthedocs.io/en/latest)

[fastgplearn document (Chinese)](https://fastgplearn.readthedocs.io/en/latest/) 
writing...


Quick Install
----------------------

```bash
pip install fastgplearn
```

License
----------------------
MIT Licence

Contact
----------------------
Developer: boliqq07: 986798607@qq.com

Support
----------------------
[![Jetbrains](./jetbrains.svg)](https://jb.gg/OpenSource)



